function [out]=abaqus_sample(samp_abaq, antype)

%% --------------------- abaqus_sample.m ------------------------------ %% 
%
% PURPOSE: Handle the sampling procedure for a given set of 
%          sample points and return the safety margin at
%          these points. 
%
% INPUT:  samp_abaq - matrix of coordinates, 
%                     each row is one sample point
%
%         antype    - analysis type,      1= plate stress at midspan
%                                         2= axial capacity
%
%
% Author: David Larsson,        davidla@stud.ntnu.no
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% plate yield at midspan
if antype==1
          mis=zeros(size(samp_abaq,1),1);
    for i=1:size(samp_abaq,1)
        delete('mises_midspan.rpt')
        runabaq(samp_abaq(i,:),antype)   % running the abaqus script
        file2=fopen('mises_midspan.rpt','r'); % opening report file
        errcount=0;                   % analysis failure operator
        while file2==-1   % if the analysis failed
            errcount=errcount+1;
            runabaq(samp_abaq(i,:),antype) % run again
            file2=fopen('mises_midspan.rpt','r'); % attempt to open
            if errcount >=5
               error('ABAQUS-Analysis has failed 5 times') 
            end
        end
        skip=fscanf(file2,' %s %s ',[1 2]);
        mises=fscanf(file2,' %f %f',[2 Inf]);  % creates matrix with 
                                      % x coordinate in row 1
                                      % stress in row 2
    fclose(file2);
    out(i)=max(mises(2,:));           % finding the max. v-m stress
   
    end  

% axial capacity
elseif antype==2    
   
        for i=1:size(samp_abaq,1)
        delete('lpf.rpt')
        runabaq(samp_abaq(i,:),antype)   % running the abaqus script
        file2=fopen('lpf.rpt','r');      % opening report file
        errcount=0;
        while file2==-1   % if the analysis failed
            errcount=errcount+1;
            runabaq(samp_abaq(i,:),antype) % run again
            file2=fopen('lpf.rpt','r'); % attempt to open
            if errcount >=5
               error('ABAQUS-Analysis has failed 5 times') 
            end
        end
        skip=fscanf(file2,' %s ',[1 2]); %skip initial text
        lpf=fscanf(file2,' %f %f ',[2 Inf]); %read LPFs
        out(i)=max(lpf(2,:));            % max capacity              
        fclose(file2);
        end
                                       
end
