function [fk]=fkcalc(f_r,f_E,i_e,z)

%% ----------------------- fkcalc.m ---------------------------------- %% 
%
% PURPOSE:   calculate f_k, characteristic buckling strength,
%            from f_r and z according to eq. 7.21 and 7.22 in
%            DNV-RP-C201            
%
% INPUT:     see dnvcheck.m and DNV-RP-C201 
%            "buckling strength of plated structures"
%
% Author: David Larsson,        davidla@stud.ntnu.no
%
% June 2015
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Calculate f_k from f_r and z;
lbar=sqrt(f_r/f_E);                 % reduced slenderness
mu=(0.34+0.08*z/i_e)*(lbar-0.2);    % imperfection coefficient

if lbar <= 0.2
fk=f_r;
else
    
fk=f_r*(1+mu+lbar^2 ...
    -sqrt((1+mu +lbar^2)^2-4*lbar^2))/(2*lbar^2);

end


end