function [z_p,z_t,sma] = smomarea(wf1,wf2,tf1,tf2,tw,hw)


%% ----------------------- smomarea.m ------------------------------ %% 
%
% PURPOSE:   calculate second moment of area, along with
%            distance from neutral axis to plate and
%            stiffener flange
%
% INPUT:     wf1: bottom flange width  (plate flange)
%            wf2: top flange width
%            tf1: bottom flange thickness (plate thickness)
%            tf2: top flange thickness
%            tw: web thickness
%            hw: web height
%
% Author: David Larsson,        davidla@stud.ntnu.no
%
% June 2015
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

A_1=wf1*tf1;
A_2=wf2*tf2;
A_w=tw*hw;
A_tot=A_1+A_2+A_w;

z_1=0.5*tf1;
z_2=tf1+hw+0.5*tf2;
z_w=tf1+0.5*hw;

na=(A_1*z_1+A_2*z_2+A_w*z_w)/A_tot;

%s.m.a without steiner contributions
sma1=(tw*hw^3+wf1*tf1^3+wf2*tf2^3)/12; 

%steiner contributions:
r1=na-tf1/2;
r2=tf1+hw+tf2/2-na;
rw=hw/2+tf1-na;
sma2=(A_1*r1*r1+A_2*r2*r2+A_w*rw*rw);

%total
sma=sma1+sma2;

z_p=abs(na)-0.5*tf1;
z_t=0.5*tf2+tf1+hw-abs(na);



end