# ********************** genmod.py ************************ 	
#							  		
# Created for ABAQUS-scripting interface                
# Part of the Master Thesis          	 	
# "Methods of Reliability Abalysis for Marine Structures"  	
#
# Norwegian University of Science and Technology      	
# Department of Marine Technology              	
# 								
# Purpose:
# Generate the model of a T-bar stiffened panel. 				
#                                                        	 
#                                                        	
# Author: David Larsson, davidla@stud.ntnu.no             	
#                                                        	
# 								
#								
# Date:   June 2015						
#								
#***********************************************************


#
# SKETCHING THE PROFILE
mysketch = myMod.ConstrainedSketch(name='CrossSection', sheetSize=4.0)

#Line segments for the plate 
mysketch.Line(point1=(-2.52, 0.0), point2=(
    -1.68, 0.0))    
mysketch.Line(point1=(-1.68, 0.0), point2=(
    -0.84, 0.0))
mysketch.Line(point1=(-0.84, 0.0), point2=(
    0.0, 0.0))    
mysketch.Line(point1=(0.0, 0.0), point2=(
    0.84, 0.0))
mysketch.Line(point1=(0.84, 0.0), point2=(
    1.68, 0.0))
mysketch.Line(point1=(1.68, 0.0), point2=(
    2.52, 0.0))

#Stiffener Webs
mysketch.Line(point1=(-1.68, 0.0), point2=(
    -1.68, 0.42))
mysketch.Line(point1=(-0.84, 0.0), point2=(
    -0.84, 0.42))
mysketch.Line(point1=(0.0, 0.0), point2=(
    0.0, 0.42))
mysketch.Line(point1=(0.84, 0.0), point2=(
    0.84, 0.42))
mysketch.Line(point1=(1.68, 0.0), point2=(
    1.68, 0.42))
    
#Stiffener flanges
mysketch.Line(point1=(-1.75, 0.42), point2=(
    -1.68, 0.42))
mysketch.Line(point1=(-1.68, 0.42), point2=(
    -1.61, 0.42))
#
mysketch.Line(point1=(-0.91, 0.42), point2=(
    -0.84, 0.42))
mysketch.Line(point1=(-0.84, 0.42), point2=(
    -0.77, 0.42))
#
mysketch.Line(point1=(-0.07, 0.42), point2=(
    0.0, 0.42))
mysketch.Line(point1=(0.0, 0.42), point2=(
    0.07, 0.42))
#    
mysketch.Line(point1=(1.75, 0.42), point2=(
    1.68, 0.42))
mysketch.Line(point1=(1.68, 0.42), point2=(
    1.61, 0.42))
#
mysketch.Line(point1=(0.91, 0.42), point2=(
    0.84, 0.42))
mysketch.Line(point1=(0.84, 0.42), point2=(
    0.77, 0.42))

# EXTRUDE AND CREATE PART
myPanel=myMod.Part(dimensionality=THREE_D, name='Panel', type=
    DEFORMABLE_BODY)
myPanel.BaseShellExtrude(depth=4.0, sketch=
    mysketch)
    
#MATERIAL
mysteel = myMod.Material(name='steel')
mysteel.Elastic(table=((ElMod, 
        0.3), ))
mysteel.Plastic(table=((YiStr, 
        0.0), (YiStr, 1.0)))
mysteel.Density(table=((7800.0, ), ))

# CREATE SECTIONS
#Plate:
myMod.HomogeneousShellSection(idealization=NO_IDEALIZATION, 
        integrationRule=SIMPSON, material='steel', name='PlateSection',
        numIntPts=5, poissonDefinition=DEFAULT, preIntegrate=OFF,
        temperature=GRADIENT, thickness=PlateThick,
        thicknessField='', thicknessModulus=None, thicknessType=
        UNIFORM, useDensity=OFF)
#Stiffener Flange
myMod.HomogeneousShellSection(idealization=NO_IDEALIZATION, 
    integrationRule=SIMPSON, material='steel', name='StiffFlangeSection', 
    numIntPts=5, poissonDefinition=DEFAULT, preIntegrate=OFF, temperature=
    GRADIENT, thickness=0.016, thicknessField='', thicknessModulus=None, 
    thicknessType=UNIFORM, useDensity=OFF)
#Stiffener web    
myMod.HomogeneousShellSection(idealization=NO_IDEALIZATION, 
    integrationRule=SIMPSON, material='steel', name='StiffWebSection', 
    numIntPts=5, poissonDefinition=DEFAULT, preIntegrate=OFF, temperature=
    GRADIENT, thickness=0.01, thicknessField='', thicknessModulus=None, 
    thicknessType=UNIFORM, useDensity=OFF)
    
# ASSIGN SECTIONS
#Plate   
myPanel.Set(faces=
    myPanel.faces.getSequenceFromMask((
    '[#c003c ]', ), ), name='PlateSet')   
myPanel.SectionAssignment(offset=0.0, 
    offsetField='', offsetType=MIDDLE_SURFACE, region=
    myPanel.sets['PlateSet'], sectionName=
    'PlateSection', thicknessAssignment=FROM_SECTION)
#Web    
myPanel.Set(faces=
    myPanel.faces.getSequenceFromMask((
    '[#12442 ]', ), ), name='WebSection')
myPanel.SectionAssignment(offset=0.0, 
    offsetField='', offsetType=MIDDLE_SURFACE, region=
    myPanel.sets['WebSection'], sectionName=
    'StiffWebSection', thicknessAssignment=FROM_SECTION)
#Flange    
myPanel.Set(faces=
    myPanel.faces.getSequenceFromMask((
    '[#12db81 ]', ), ), name='FlangeSet')
myPanel.SectionAssignment(offset=0.0, 
    offsetField='', offsetType=MIDDLE_SURFACE, region=
    myPanel.sets['FlangeSet'], sectionName=
    'StiffFlangeSection', thicknessAssignment=FROM_SECTION)
   
#LOCAL MATERIAL ORIENTATIONS 
myPanel.DatumCsysByThreePoints(coordSysType=
    CARTESIAN, name='PlateCoord', origin=
    myPanel.vertices[8], point1=
    myPanel.InterestingPoint(
    myPanel.edges[11], MIDDLE), point2=
    myPanel.InterestingPoint(
    myPanel.edges[13], MIDDLE))
myPanel.DatumCsysByThreePoints(coordSysType=
    CARTESIAN, name='WebCoord', origin=
    myPanel.InterestingPoint(
    myPanel.edges[11], MIDDLE), point1=
    myPanel.vertices[9], point2=
    myPanel.InterestingPoint(
    myPanel.edges[42], MIDDLE))
myPanel.DatumCsysByThreePoints(coordSysType=
    CARTESIAN, name='FlangeCoord', origin=
    myPanel.InterestingPoint(
    myPanel.edges[35], MIDDLE), point1=
    myPanel.vertices[26], point2=
    myPanel.InterestingPoint(
    myPanel.edges[39], MIDDLE))
myPanel.MaterialOrientation(
    additionalRotationField='', additionalRotationType=ROTATION_NONE,
    angle=0.0, axis=AXIS_3, fieldName='', localCsys=
    myPanel.datums[5], orientationType=SYSTEM, 
    region=myPanel.sets['PlateSet'])
myPanel.MaterialOrientation(
    additionalRotationField='', additionalRotationType=ROTATION_NONE,
    angle=0.0, axis=AXIS_3, fieldName='', localCsys=
    myPanel.datums[7], orientationType=SYSTEM, 
    region=myPanel.sets['FlangeSet'])
myPanel.MaterialOrientation(
    additionalRotationField='', additionalRotationType=ROTATION_NONE,
    angle=0.0, axis=AXIS_3, fieldName='', localCsys=
    myPanel.datums[6], orientationType=SYSTEM, 
    region=myPanel.sets['WebSection'])

# CREAT ASSEMBLY AND PART INSTANCE
myAssembly = myMod.rootAssembly
myInstance = myAssembly.Instance(dependent=ON, name='plateInstance', 
    part=myPanel)    

#MESHING
myPanel.setMeshControls(elemShape=QUAD, regions=
    myPanel.faces.getSequenceFromMask((
    '[#13ffc3 ]', ), ))
myPanel.setMeshControls(elemShape=QUAD, regions=
    myPanel.faces.getSequenceFromMask((
    '[#c003c ]', ), ))
myPanel.setElementType(elemTypes=(ElemType(
    elemCode=S4R, elemLibrary=STANDARD, secondOrderAccuracy=OFF, 
    hourglassControl=DEFAULT), ElemType(elemCode=S3,
    elemLibrary=STANDARD)), 
    regions=(myPanel.faces.getSequenceFromMask((
    '[#1fffff ]', ), ), ))
myPanel.seedPart(deviationFactor=0.1, 
    minSizeFactor=0.1, size=0.2)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#4124922 #1008 ]', ), ), minSizeFactor=0.1, size=0.1)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#4124922 #1008 ]', ), ), minSizeFactor=0.1, size=0.05)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#4124922 #1008 ]', ), ), minSizeFactor=0.1, size=0.08)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#4124922 #1008 ]', ), ), minSizeFactor=0.1, size=0.05)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#ab680055 #a05eaf67 ]', ), ), minSizeFactor=0.1, size=0.05)
myPanel.seedPart(deviationFactor=0.1, 
    minSizeFactor=0.1, size=0.01)
myPanel.seedPart(deviationFactor=0.1, 
    minSizeFactor=0.1, size=0.1)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#50800008 #40214080 ]', ), ), minSizeFactor=0.1, size=0.05)
myPanel.seedEdgeBySize(constraint=FINER, 
    deviationFactor=0.1, edges=
    myPanel.edges.getSequenceFromMask((
    '[#ab400005 #a052a954 ]', ), ), minSizeFactor=0.1, size=0.02)
myPanel.generateMesh()

#NODE SETS AND REFERENCE POINTS CONSTRAINTS
myAssembly.regenerate()


# Create node sets on edges
myAssembly.Set(name='leftnodes', nodes=
    myInstance.nodes.getSequenceFromMask(mask=(
    '[#d34d5553 #3554 #0:4 #1fc000 #0:2 #3f800 #0:2', 
    ' #7f00 #0:2 #fe0 #0:2 #1fc #0 #80000000', 
    ' #3f #0 #30000000 #0:2 #18000 #0:4 #e0000', 
    ' #0:2 #701fc0 #0:4 #7000000 #0:2 #180fe000 #0:4', 
    ' #e0000000 #0:2 #1fc0000 #7 #0 #fe00000 #0:2',
    ' #1fc0000 #0:2 #38000 ]', ), ))
        
myAssembly.Set(name='rightnodes', nodes=
    myInstance.nodes.getSequenceFromMask(mask=(
    '[#2cb2aaac #aab #0 #60000000 #0:5 #7f0 #0:2', 
    ' #fe #0 #c0000000 #1f #0 #f8000000 #3', 
    ' #0 #7f000000 #0:2 #fe00000 #0:2 #6000 #0:2', 
    ' #3 #0:4 #fe038 #0:2 #1c0 #0:4 #7f01c00', 
    ' #0:2 #3000 #0:4 #fe038000 #0:2 #1c0000 #0:2',
    ' #fe03f800 #0:5 #e ]', ), ))
    
leftRP = myAssembly.ReferencePoint(point=
         (0.0,0.0,4.0))
rightRP = myAssembly.ReferencePoint(point=
     	 (0.0,0.0,0.0))
myMod.RigidBody(name='left_constraint', pinRegion=
    myAssembly.sets['leftnodes'], refPointRegion=
    Region(referencePoints=(
    myAssembly.referencePoints[leftRP.id], )))
myMod.RigidBody(name='right_constraint', pinRegion=
    myAssembly.sets['rightnodes'], refPointRegion=
    Region(referencePoints=(
    myAssembly.referencePoints[rightRP.id], )))
    
# APPLY IMPERFECTIONS
#new matrix for nodal coordinates
Coor=zeros((len(myPanel.nodes),3))
	

#assigning new nodal coordinates
rep=0
for i in myPanel.nodes:
    Coor[i.label-1][0]=i.coordinates[0]
    Coor[i.label-1][1]=i.coordinates[1]+imperf*sin(i.coordinates[2]*pi / 4)
    Coor[i.label-1][2]=i.coordinates[2]
    rep=rep+1
myPanel.editNode(
    nodes=myPanel.nodes,
    coordinates=Coor)
    
    
    
