from abaqus import *
from abaqusConstants import *
from part import *
from material import *
from section import *
from assembly import *
from step import *
from interaction import *
from load import *
from mesh import *
from optimization import *
from job import *
from sketch import *
from visualization import *
from connectorBehavior import *
from math import *
from numpy import *

backwardCompatibility.setValues(includeDeprecated=True,
                                reportDeprecated=True)

#LOAD VARIABLES
execfile('Var.py')
ElMod = 206000000000


#Create Model
myMod = mdb.Model(name='StiffPanel')
execfile('genmod.py')

#INITIAL STEP
# Impose BC on left edge (through reference point constraints)
myMod.DisplacementBC(amplitude=UNSET, createStepName='Initial', 
    distributionType=UNIFORM, fieldName='', localCsys=None, name='BC_left', 
    region=Region(referencePoints=(
    myAssembly.referencePoints[leftRP.id], )), u1=SET, u2=SET, 
    u3=UNSET, ur1=UNSET, ur2=SET, ur3=SET)
    
# Impose BC on right edge (through reference point constraints)    
myMod.DisplacementBC(amplitude=UNSET, createStepName='Initial', 
    distributionType=UNIFORM, fieldName='', localCsys=None, name='BC-2', 
    region=Region(referencePoints=(
    myAssembly.referencePoints[rightRP.id], )), u1=SET, u2=SET, 
    u3=SET, ur1=UNSET, ur2=SET, ur3=SET)


# Create set on Long. Edges  
myAssembly.Set(edges=
    myInstance.edges.getSequenceFromMask(
    ('[#0 #11000000 ]', ), ), name='Set-7')
    
# Impose BC on longitudinal edges    
myMod.DisplacementBC(amplitude=UNSET, createStepName='Initial', 
    distributionType=UNIFORM, fieldName='', localCsys=None, name='BC-3', 
    region=myAssembly.sets['Set-7'], u1=SET, u2=SET, 
    u3=UNSET, ur1=UNSET, ur2=UNSET, ur3=UNSET)   

#STEP1
#Create step
myMod.StaticStep(name='loadstep', nlgeom=ON, previous='Initial',
	timePeriod=1.0, initialInc=0.1)

# Create surface on plate face for pressure load
pSurf = myAssembly.Surface(name='plateSurf', side1Faces=
           myInstance.faces.getSequenceFromMask(
           ('[#c003c ]', ), ))

# Create pressure load
myMod.Pressure(amplitude=UNSET, createStepName='loadstep', 
        distributionType=UNIFORM, field='', magnitude=LatPress, name='pLoad', 
    region=pSurf)
    
# Assign force to the reference point on left side    
myAssembly.Set(name='Set-8', referencePoints=(
    myAssembly.referencePoints[leftRP.id], ))
myMod.ConcentratedForce(cf3=-AxF, createStepName='loadstep'
    , distributionType=UNIFORM, field='', localCsys=None, name='Load-2', 
    region=myAssembly.sets['Set-8'])
    
# CREATE JOB AND SUBMIT  
myJob= mdb.Job(atTime=None, contactPrint=OFF, description='', echoPrint=ON, 
	        explicitPrecision=SINGLE, getMemoryFromAnalysis=True, historyPrint=OFF, 
	        memory=90, memoryUnits=PERCENTAGE, model=myMod, modelPrint=OFF, 
	        multiprocessingMode=DEFAULT, name='MISESLIN', nodalOutputPrecision=SINGLE, 
	        numCpus=1, numGPUs=0, queue=None, resultsFormat=ODB, scratch='', type=
	        ANALYSIS, userSubroutine='', waitHours=0, waitMinutes=0)
	        
myJob.submit()
#myJob.waitForCompletion()

# PRINT MIDSPAN STRESS TO FILE:

execfile('misesmidODB.py')

